""" Server Config Definition """

import configparser
import os
from typing import Any, Optional

from pydantic import BaseModel


class ServerConfig(BaseModel):
    """
    Server Configuration

    Attributes
    ----------
    config_file_path: Optional[str] = "rowantree.config"
        The config file for the service.
    log_dir: Optional[str]
        The log directory.
    """

    config_file_path: Optional[str] = "rowantree.config"
    log_dir: Optional[str]

    def __init__(self, **data: Any):
        super().__init__(**data)
        config = configparser.ConfigParser()
        config.read(self.config_file_path)

        # Directory Options
        self.log_dir = config.get("DIRECTORY", "logs_dir")

        if "LOGS_DIR" in os.environ:
            self.log_dir = os.environ["LOGS_DIR"]



""" Content Service Entry Point """

import logging
import os
from pathlib import Path

from rowantree.service.sdk import RowanTreeService

from .common.personality import Personality
from .config.server import ServerConfig

if __name__ == "__main__":
    # Generating server configuration
    config: ServerConfig = ServerConfig()

    # Setup logging
    Path(config.log_dir).mkdir(parents=True, exist_ok=True)
    logging.basicConfig(
        format="%(asctime)s - %(levelname)s - %(message)s",
        datefmt="%m/%d/%Y %I:%M:%S %p",
        level=logging.DEBUG,
        filemode="w",
        filename=f"{config.log_dir}/{os.uname()[1]}.therowantree.server.log",
    )

    logging.debug("Starting server")

    logging.debug(config.json(by_alias=True, exclude_unset=True))

    me: Personality = Personality(rowantree_service=RowanTreeService())

    logging.debug("Starting contemplation loop")
    while True:
        me.contemplate()
